@@ -13,9 +13,6 @@
 # limitations under the License.
 """Tests for dsub.lib.param_util."""
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import datetime
 import doctest
 import os
@@ -26,7 +23,6 @@ from dsub.lib import job_model
 from dsub.lib import param_util
 import parameterized
 import pytz
-import six
 
 
 # Fixed values for age_to_create_time
@@ -104,7 +100,8 @@ class ParamUtilTest(unittest.TestCase):
   ])
   def test_compute_create_time_fail(self, unused_name, age):
     del unused_name
-    with six.assertRaisesRegex(self, ValueError, 'Unable to parse age string'):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError,
+                                             'Unable to parse age string'):
       _ = param_util.age_to_create_time(age)
 
   @parameterized.parameterized.expand([
@@ -125,7 +122,8 @@ class ParamUtilTest(unittest.TestCase):
   ])
   def test_timeout_in_seconds_fail(self, unused_name, timeout):
     del unused_name
-    with six.assertRaisesRegex(self, ValueError, 'Unable to parse interval'):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError,
+                                             'Unable to parse interval'):
       _ = param_util.timeout_in_seconds(timeout)
 
   @parameterized.parameterized.expand([
@@ -146,7 +144,8 @@ class ParamUtilTest(unittest.TestCase):
   ])
   def test_log_interval_in_seconds_fail(self, unused_name, log_interval):
     del unused_name
-    with six.assertRaisesRegex(self, ValueError, 'Unable to parse interval'):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError,
+                                             'Unable to parse interval'):
       _ = param_util.log_interval_in_seconds(log_interval)
 
 
@@ -330,7 +329,7 @@ class FileParamUtilTest(unittest.TestCase):
   def test_output_val_err(self, unused_name, recursive, uri, regex):
     del unused_name
     file_param_util = param_util.OutputFileParamUtil('output')
-    with six.assertRaisesRegex(self, ValueError, regex):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError, regex):
       file_param_util.parse_uri(uri, recursive)
 
   @parameterized.parameterized.expand([
@@ -341,7 +340,7 @@ class FileParamUtilTest(unittest.TestCase):
   def test_file_provider_err(self, unused_name, uri, regex):
     del unused_name
     file_param_util = param_util.OutputFileParamUtil('output')
-    with six.assertRaisesRegex(self, ValueError, regex):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError, regex):
       file_param_util.parse_file_provider(uri)
 
   @parameterized.parameterized.expand([
@@ -408,7 +407,8 @@ class TestSubmitValidator(unittest.TestCase):
     job_resources = job_model.Resources(
         logging=job_model.LoggingParam('gs://buck/logs', job_model.P_GCS))
     err_expected = 'Unsupported %s path (%s) for provider' % (name, path)
-    with six.assertRaisesRegex(self, ValueError, re.escape(err_expected)):
+    with unittest.TestCase.assertRaisesRegex(self, ValueError,
+                                             re.escape(err_expected)):
       param_util.validate_submit_args_or_fail(
           job_model.JobDescriptor(None, job_params, job_resources,
                                   TASK_DESCRIPTORS),
